@@ -65,7 +65,7 @@ class WorkflowBuilder:
         # these are provided by the workflowutils container
         utils_container = Container("workflowutils",
                                     Container.SINGULARITY,
-                                    image="library://geoedfproject/framework/workflowutils:latest",
+                                    image="library://framework/workflowutils:latest",
                                     mounts=["%s:/data/%s" % (self.job_dir,self.workflow_id)])
         self.tc.add_containers(utils_container)
 
@@ -316,7 +316,7 @@ class WorkflowBuilder:
             
             self.tc.add_transformations(proc_exec)
 
-        self.tc.write()
+        self.tc.write('%s/transformations.yml' % self.run_dir)
             
     # build replica catalog
     def build_replica_catalog(self):
@@ -343,13 +343,15 @@ class WorkflowBuilder:
         # create a local run directory; this will be used to store subdax YAMLs and intermediate
         # outputs
         # these will just be workflow outputs and we rely on Pegasus to establish linkages
-        # self.run_dir = self.helper.create_run_dir()
+        # in production mode, this will be used to store the workflow and TC and receive outputs
+        # from submit
+        self.run_dir = self.helper.create_run_dir()
 
         # build the transformation catalog
         self.build_transformation_catalog()
 
-        # build replica catalog
-        self.build_replica_catalog()
+        # build replica catalog (turning off since we don't have a need for a RC)
+        # self.build_replica_catalog()
 
         # leaf job used to manage dependencies across stages
         self.leaf_job = None
@@ -604,7 +606,7 @@ class WorkflowBuilder:
             # args with dir modifiers
             dir_mod_refs_str = self.helper.list_to_str(proc_inst.dir_modified_refs)
 
-            subdax_job = self.construct_plugin_subdax(stage_id, subdax_filepath, plugin_name=plugin_name, stage_refs_str=stage_refs_str, local_file_args_str=local_file_args_str, sensitive_arg_binds_str=sensitive_arg_binds_str, dir_mod_refs_str = dir_mod_refs_str, stage_ref_files=stage_ref_files)
+            subdax_job = self.construct_plugin_subdax(stage_id, subdax_filename, plugin_name=plugin_name, stage_refs_str=stage_refs_str, local_file_args_str=local_file_args_str, sensitive_arg_binds_str=sensitive_arg_binds_str, dir_mod_refs_str = dir_mod_refs_str, stage_ref_files=stage_ref_files)
             subdax_job.add_outputs(subdax_file,stage_out=False,register_replica=False)
             self.geoedf_wf.add_jobs(subdax_job)
 
